ProfilingAllocator

Struct ProfilingAllocator 

pub struct ProfilingAllocator<const CPU_FREQ: u32 = 99>;
A profiling allocator that wraps the system allocator.

The const generic CPU_FREQ specifies the CPU sampling frequency in Hz. Set to 0 to disable CPU profiling.

When the heap feature is enabled, this allocator captures allocation and deallocation events along with stack traces. CPU profiling (if enabled) starts automatically on the first allocation.

When profiling features are disabled, it’s a zero-cost passthrough.

Implementations

Source

impl<const CPU_FREQ: u32> ProfilingAllocator<CPU_FREQ>

pub const fn new() -> Self